/********************************************************
 *  WINBOND W569 MIDDLEWARE DEFINE FILE
 *
 *  FILENAME:
 *    MWDefine.h
 *
 *  MODIFICATION HISTORY:
 *    2004/08/02	created		by	CCChien0
 ********************************************************/
#ifndef	_MWDefine_h_
#define	_MWDefine_h_

// select chip part no, only one of following can be 1
#define	W56940_64	0
#define	W56932		1
	#if	W56932
		#define	USE_SERIAL_INTERFACE	0
	#endif

// playback format support
#define	SUPPORT_CMF		1
#define	SUPPORT_SPEECH	0

// support LED/Motor control
#define	SUPPORT_LED_CONTROL	0
#define	SUPPORT_MTR_CONTROL	0

// PLL output clock = CLKI  * ((PLL_ADJUST_M+4)/PLL_ADJUST_N) * (1/6)
// for 15MHz CLKI
//#define	CLKI				15000000
//#define	PLL_ADJUST_N		13
//#define	PLL_ADJUST_M		49

// for 22MHz CLKI
#define	CLKI				22000000
#define	PLL_ADJUST_N		25
#define	PLL_ADJUST_M		66

//for 27MHz CLKI
//#define	CLKI				27000000
//#define	PLL_ADJUST_N		26
//#define	PLL_ADJUST_M		55

// VDS: Speaker amplifier center voltage setting
//	Center voltage (V)	VDD		SPKVDD
// = 0:     0.6 xVDD		3.0V	3.6V
// = 1:     0.5 xVDD		3.0V	3.0V
// = 2:     0.67xVDD		2.7V	3.6V
// = 3:		0.72xVDD		2.5V	3.6V
#define	SPK_VOL_REG_VDS			0


#if W56940_64
	// select pin10~11 for digital_output_port / headphone output
	// 0: headphone output
	// 1: digital_output_port (LED)
	#define DOUT_LED			1
#endif

#define	MELODY_FIFO_SIZE		256
#define	MELODY_FIFO_FILL_SIZE	128
#define	SPEECH_FIFO_SIZE		256
#define	SPEECH_FIFO_FILL_SIZE	128

// return value definition
#define	MW_NO_ERROR					(0)		/* no error */
#define	MW_ERROR					(-1)	/* error */
#define	MW_ERROR_ARGUMENT			(-2)	/* error of arguments */
#define	MW_ERROR_RESOURCE_OVER		(-3)	/* over resource limitation */
#define	MW_ERROR_ID					(-4)	/* error id number */

#define	MW_ERROR_FILE				(-16)	/* error of file operation */
#define	MW_ERROR_CONTENTS_CLASS		(-17)	/* SMAF Contents Class shows can't play */
#define	MW_ERROR_CONTENTS_TYPE		(-18)	/* SMAF Contents Type shows can't play */
#define	MW_ERROR_CHUNK_SIZE			(-19)	/* illegal SMAF Chunk Size value */
#define	MW_ERROR_CHUNK				(-20)	/* illegal SMAF Track Chunk value */
#define	MW_ERROR_UNMATCHED_TAG		(-21)	/* unmathced specified TAG */
#define	MW_ERROR_SHORT_LENGTH		(-22)	/* short sequence */

#define	MW_ERROR_SEND_COMMAND		(-32)	/* error while sending command */
#define	MW_ERROR_API_REENTRANT		(-33)	/* error if API called while another API does not finish */

//format sequence same as abyFileFormatGUID
#define	FORMAT_IMF	0
#define	FORMAT_SPH  1
#define	FORMAT_CMF  2
#define	FORMAT_MBN  3
#define	FORMAT_CBN  4
#define	FORMAT_SMF  5

// speech format
#define 	eSPEECH_FORMAT_UNKNOWN					-1
#define 	eSPEECH_FORMAT_SIGN_8BIT_PCM			0x00
#define 	eSPEECH_FORMAT_SIGN_16BIT_PCM			0x01
#define 	eSPEECH_FORMAT_APM						0x03

#define	DEBUG_printf 0

// clock information
#define	PLLOUT						(CLKI * (PLL_ADJUST_M + 4) / (float)PLL_ADJUST_N)
#define	W56964_SYSTEM_CLOCK		(PLLOUT / 8.0f)
#define	W56964_NEW_SYSTEM_CLOCK	(PLLOUT / 6.0f)
#define	TCLK						(PLLOUT / 2)
#define	ALLOWED_SAMPLE_RATE		(TCLK / 1280)

#if	SUPPORT_LED_CONTROL

typedef struct
{
	BYTE	byMode;		// Designates LED control method.
						// 0: OFF
						// 1: Synchronizer sync. (synthesizer KeyOn sync.)
						// 2: Synchronizer sync. + Blinking control
						// 3: LED designation (sync. with command LED On/Off)
						// 4: LED designation + Blinking control
	WORD	wSyncChannel;
} S_LEDSetting;

#endif

#if	SUPPORT_MTR_CONTROL

typedef struct
{
	BYTE	byMode;		// Designates Motor control method.
						// 0: OFF
						// 1: Synchronizer sync. (synthesizer KeyOn sync.)
						// 2: Synchronizer sync. + Blinking control
						// 3: MTR designation (sync. with command Motor On/Off)
						// 4: MTR designation + Blinking control
						// 5: Melody event sync. (sync. with melody event Motor On/Off)
						// 6: Melody event sync. + Blinking control
	WORD	wSyncChannel;
}S_MotorSetting;

#endif


#endif	/* _MWDefine_h_ */

